@@ -20,6 +20,8 @@ class OsefStream:
     The sever may close the socket if client is too late.
     """
 
+    TIMEOUT = 2
+
     def __init__(self, path: str):
         self._path = path
         self._parsed_path = urlparse(self._path)
@@ -51,7 +53,8 @@ class OsefStream:
 
     def open_socket(self):
         """Open tcp socket on provided path.
-        Tries to connect again if ConnectionRefusedError is raised"""
+        Tries to connect again if ConnectionRefusedError is raised
+        """
         tcp_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         while True:
             try:
@@ -60,7 +63,7 @@ class OsefStream:
                 )
                 break
             except ConnectionRefusedError:
-                time.sleep(0.1)
+                time.sleep(0.005)
                 continue
         self._io_stream = tcp_socket
 
@@ -265,14 +268,17 @@ def _parse_raw_to_tuple(raw_tree: _TreeNode) -> Tuple[str, Any]:
 
     # For non-leaves, add each child to a dictionary
     tree = {}
-    children_list = []
+    if type_info.node_info.type == list:
+        tree = []
+
     for child in children:
         child_name, child_tree = _parse_raw_to_tuple(child)
-        if type_info.node_info.type == list:
-            children_list.append({child_name: child_tree})
-            tree = children_list
-        elif type_info.node_info.type == dict:
+
+        if type_info.node_info.type == dict:
             tree[child_name] = child_tree
+        elif type_info.node_info.type == list:
+            tree.append({child_name: child_tree})
         else:
             raise ValueError("Unsupported internal node type.")
+
     return type_info.name, tree
