@@ -1,4 +1,6 @@
 """Tools to save osef stream to a file."""
+import logging
+
 from osef import parser
 
 
@@ -23,21 +25,23 @@ def save_osef_from_tcp(
     :return: None
     """
     with open(output_filename, "wb") as output:
-        osef_input = parser.open_osef(tcp_input)
-        if not osef_input:
-            return None
-        bytes_written = 0
-
-        while True:
-            try:
-                read = osef_input.read()
-                if read is None or len(read) == 0:
+        with parser.OsefStream(tcp_input) as osef_stream:
+            if not osef_stream:
+                return None
+            bytes_written = 0
+            count = 0
+            while True:
+                try:
+                    read = osef_stream.read()
+                    if read is None or len(read) == 0:
+                        break
+                    output.write(read)
+                    bytes_written += len(read)
+                    count += 1
+                    if print_progress and not count % 1000:
+                        logging.info(f"Current file size: {pretty_size(bytes_written)}")
+                except KeyboardInterrupt:
                     break
-                output.write(read)
-                bytes_written += len(read)
-                if print_progress:
-                    print(f"\r{pretty_size(bytes_written)}", end="")
-            except KeyboardInterrupt:
-                break
-        osef_input.close()
-        return bytes_written
+                except EOFError:
+                    break
+            return bytes_written
